Xitem class

Represents a metadata item from the EPUB's package file.

Constructors

Xitem(XmlElement xi)
Creates a new Xitem instance from an XML element.

Properties

attributes Map<String, String>
A map of attributes for the metadata item.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the metadata item.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value of the metadata item.
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(XmlElement xe) List<Xitem>
Parses a list of Xitem instances from an XML element.